Console class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

d(dynamic message, {DateTime? time, Object? error, StackTrace? stackTrace}) → void
dispose() → void
e(dynamic message, {DateTime? time, Object? error, StackTrace? stackTrace}) → void
f(dynamic message, {DateTime? time, Object? error, StackTrace? stackTrace}) → void
i(dynamic message, {DateTime? time, Object? error, StackTrace? stackTrace}) → void
log(Level level, dynamic message, {DateTime? time, Object? error, StackTrace? stackTrace}) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
t(dynamic message, {DateTime? time, Object? error, StackTrace? stackTrace}) → void
toString() String
A string representation of this object.
inherited
w(dynamic message, {DateTime? time, Object? error, StackTrace? stackTrace}) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance Console
final