InvokeModel class

Constructors

InvokeModel({String? methodName, List<Object>? arguments, String? listenMethodName})

Properties

arguments List<Object>?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
listenMethodName String?
getter/setter pair
methodName String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited